# PyGenericSpreadSheet
Generic Spreadsheet Editing API

[![pypi](https://img.shields.io/pypi/pyversions/PyGenericSpreadSheet)](https://pypi.org/project/PyGenericSpreadSheet/)
[![Github Actions Build](https://github.com/WolfgangFahl/PyGenericSpreadSheet/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/PyGenericSpreadSheet/actions?query=workflow%3ABuild+branch%3Amain)
[![PyPI Status](https://img.shields.io/pypi/v/PyGenericSpreadSheet.svg)](https://pypi.python.org/pypi/PyGenericSpreadSheet/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/PyGenericSpreadSheet.svg)](https://github.com/WolfgangFahl/PyGenericSpreadSheet/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/PyGenericSpreadSheet.svg)](https://github.com/WolfgangFahl/PyGenericSpreadSheet/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/WolfgangFahl/PyGenericSpreadSheet.svg)](https://www.apache.org/licenses/LICENSE-2.0)

## Documentation
[Wiki](http://wiki.bitplan.com/index.php/PyGenericSpreadSheet)

## Dockerize
``` bash
docker build -t pygenericspreadsheet -f .\Dockerfile .
```
``` bash
docker run --rm -it -v ${PWD}:"/mnt" -w "/mnt" pygenericspreadsheet /bin/bash
```

### Authors
* [Tim Holzheim](https://www.semantic-mediawiki.org/wiki/Tim_Holzheim)
* [Wolfgang Fahl](http://www.bitplan.com/Wolfgang_Fahl)
* [Michal Slupczynski](https://dbis.rwth-aachen.de/dbis/index.php/user/slupczynskim/)